@@ -4,7 +4,7 @@
 
 package Glib::MakeHelper;
 
-our $VERSION = '1.322';
+our $VERSION = '1.325';
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ sub do_pod_files
 	# try to get it from pwd first, then fall back to installed
 	# this is so Glib will get associated copy, and everyone else
 	# should use the installed glib copy
-	eval { require 'lib/Glib/ParseXSDoc.pm'; 1; } or require Glib::ParseXSDoc;
+	eval { require './lib/Glib/ParseXSDoc.pm'; 1; } or require Glib::ParseXSDoc;
 	$@ = undef;
 	import Glib::ParseXSDoc;
 
@@ -453,7 +453,7 @@ Create and return the text of Makefile rules to manage building RPMs.
 You'd put this in your Makefile.PL's MY::postamble.
 
 I<HASH> is a set of search and replace keys for the spec file.  All 
-occurences of @I<key>@ in the spec file template perl-$(DISTNAME).spec.in
+occurrences of @I<key>@ in the spec file template perl-$(DISTNAME).spec.in
 will be replaced with I<value>.  'VERSION' and 'SOURCE' are supplied for
 you.  For example:
 
